==> ginkgo-hpc-docs-1.9.0-4-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/classgko_1_1matrix_1_1Csr.js <==
var classgko_1_1matrix_1_1Csr =
[
    [ "automatical", "classgko_1_1matrix_1_1Csr_1_1automatical.html", "classgko_1_1matrix_1_1Csr_1_1automatical" ],
    [ "classical", "classgko_1_1matrix_1_1Csr_1_1classical.html", "classgko_1_1matrix_1_1Csr_1_1classical" ],
    [ "cusparse", "classgko_1_1matrix_1_1Csr_1_1cusparse.html", "classgko_1_1matrix_1_1Csr_1_1cusparse" ],
    [ "load_balance", "classgko_1_1matrix_1_1Csr_1_1load__balance.html", "classgko_1_1matrix_1_1Csr_1_1load__balance" ],
    [ "merge_path", "classgko_1_1matrix_1_1Csr_1_1merge__path.html", "classgko_1_1matrix_1_1Csr_1_1merge__path" ],
    [ "sparselib", "classgko_1_1matrix_1_1Csr_1_1sparselib.html", "classgko_1_1matrix_1_1Csr_1_1sparselib" ],
    [ "strategy_type", "classgko_1_1matrix_1_1Csr_1_1strategy__type.html", "classgko_1_1matrix_1_1Csr_1_1strategy__type" ],
    [ "Csr", "classgko_1_1matrix_1_1Csr.html#a9094bdf34a8c56f115252f0fe5a7f5ae", null ],
    [ "Csr", "classgko_1_1matrix_1_1Csr.html#aee53e78f8b1f8e3d2a6c407baac456d9", null ],
    [ "compute_absolute", "classgko_1_1matrix_1_1Csr.html#a2435b1ff883ca33fa3874bc81aada57b", null ],
    [ "compute_absolute_inplace", "classgko_1_1matrix_1_1Csr.html#ab4cc1ed324551291d385d317e75ad256", null ],
    [ "conj_transpose", "classgko_1_1matrix_1_1Csr.html#af57eb59b5acb36cae0b3a16ffff9cf4f", null ],
    [ "create_submatrix", "classgko_1_1matrix_1_1Csr.html#a714b3534b309ecb2bb05958dbbf4885e", null ],
    [ "create_submatrix", "classgko_1_1matrix_1_1Csr.html#a2d1d5b4b310ed444ccbb178e241a9822", null ],
    [ "extract_diagonal", "classgko_1_1matrix_1_1Csr.html#a75ddc647a3998ca75e15ac8cd29c24ce", null ],
    [ "get_col_idxs", "classgko_1_1matrix_1_1Csr.html#ae701fb37da0c745c314fb3472cef5df4", null ],
    [ "get_const_col_idxs", "classgko_1_1matrix_1_1Csr.html#ac3a1ef745f900fd534999a69eae3ff32", null ],
    [ "get_const_row_ptrs", "classgko_1_1matrix_1_1Csr.html#a29e603a026ca798346e74ee8408b2f51", null ],
    [ "get_const_srow", "classgko_1_1matrix_1_1Csr.html#a396e0e99ce4fefca9dcbe45e4fccc838", null ],
    [ "get_const_values", "classgko_1_1matrix_1_1Csr.html#aad85907f0b9717618ed5dabcd56e4e39", null ],
    [ "get_num_srow_elements", "classgko_1_1matrix_1_1Csr.html#a5b8c25c2fb1bbea62a3afdec8f8340c5", null ],
    [ "get_num_stored_elements", "classgko_1_1matrix_1_1Csr.html#ab70c085fc3df11a4ed9fe74b40844c5c", null ],
    [ "get_row_ptrs", "classgko_1_1matrix_1_1Csr.html#a83f2a63175bbffa39808543a3d4b3f3b", null ],
    [ "get_srow", "classgko_1_1matrix_1_1Csr.html#a4a8d2975871fdd779e447a8ef9e991d1", null ],
    [ "get_strategy", "classgko_1_1matrix_1_1Csr.html#abb20626b04360436259fdc13b00e59b0", null ],
    [ "get_values", "classgko_1_1matrix_1_1Csr.html#ade22bdc09b0ef6d9740feeaa702fdd51", null ],
    [ "inv_scale", "classgko_1_1matrix_1_1Csr.html#a3ed41ecd59dcfe1b805ed910fada56a9", null ],
    [ "operator=", "classgko_1_1matrix_1_1Csr.html#a0f8038628e96f1995e4942863415ad63", null ],
    [ "operator=", "classgko_1_1matrix_1_1Csr.html#a96d132e8d22d7565f93540eb50bcc32c", null ],
    [ "permute", "classgko_1_1matrix_1_1Csr.html#a898b9b458ff9e26c87c277fba3a9bdae", null ],
    [ "permute", "classgko_1_1matrix_1_1Csr.html#af0538658a2fad819129927dbd39de0ae", null ],
    [ "scale", "classgko_1_1matrix_1_1Csr.html#ad1db62aaad519a9774dde49ff411edde", null ],
    [ "scale_permute", "classgko_1_1matrix_1_1Csr.html#a1c3c66d3baf3b05e52992b6f3f7611f7", null ],
    [ "scale_permute", "classgko_1_1matrix_1_1Csr.html#acf9d804a766061d117e78a3534b2e80d", null ],
    [ "set_strategy", "classgko_1_1matrix_1_1Csr.html#a3e0f6f2a9d773de0551068d514bf9703", null ],
    [ "sort_by_column_index", "classgko_1_1matrix_1_1Csr.html#ac817665ebedfc099180a785d813db8ef", null ],
    [ "transpose", "classgko_1_1matrix_1_1Csr.html#aaa850dcdfabfc020918fa870e50c0b11", null ]
];

==> ginkgo-hpc-docs-1.10.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/classgko_1_1matrix_1_1Csr.js <==
var classgko_1_1matrix_1_1Csr =
[
    [ "automatical", "classgko_1_1matrix_1_1Csr_1_1automatical.html", "classgko_1_1matrix_1_1Csr_1_1automatical" ],
    [ "classical", "classgko_1_1matrix_1_1Csr_1_1classical.html", "classgko_1_1matrix_1_1Csr_1_1classical" ],
    [ "cusparse", "classgko_1_1matrix_1_1Csr_1_1cusparse.html", "classgko_1_1matrix_1_1Csr_1_1cusparse" ],
    [ "load_balance", "classgko_1_1matrix_1_1Csr_1_1load__balance.html", "classgko_1_1matrix_1_1Csr_1_1load__balance" ],
    [ "merge_path", "classgko_1_1matrix_1_1Csr_1_1merge__path.html", "classgko_1_1matrix_1_1Csr_1_1merge__path" ],
    [ "permuting_reuse_info", "structgko_1_1matrix_1_1Csr_1_1permuting__reuse__info.html", "structgko_1_1matrix_1_1Csr_1_1permuting__reuse__info" ],
    [ "sparselib", "classgko_1_1matrix_1_1Csr_1_1sparselib.html", "classgko_1_1matrix_1_1Csr_1_1sparselib" ],
    [ "strategy_type", "classgko_1_1matrix_1_1Csr_1_1strategy__type.html", "classgko_1_1matrix_1_1Csr_1_1strategy__type" ],
    [ "Csr", "classgko_1_1matrix_1_1Csr.html#a9094bdf34a8c56f115252f0fe5a7f5ae", null ],
    [ "Csr", "classgko_1_1matrix_1_1Csr.html#aee53e78f8b1f8e3d2a6c407baac456d9", null ],
    [ "compute_absolute", "classgko_1_1matrix_1_1Csr.html#a2435b1ff883ca33fa3874bc81aada57b", null ],
    [ "compute_absolute_inplace", "classgko_1_1matrix_1_1Csr.html#ab4cc1ed324551291d385d317e75ad256", null ],
    [ "conj_transpose", "classgko_1_1matrix_1_1Csr.html#af57eb59b5acb36cae0b3a16ffff9cf4f", null ],
    [ "create_const_value_view", "classgko_1_1matrix_1_1Csr.html#a8c1115150d40666b4df0eacbacfd474e", null ],
    [ "create_submatrix", "classgko_1_1matrix_1_1Csr.html#a714b3534b309ecb2bb05958dbbf4885e", null ],
    [ "create_submatrix", "classgko_1_1matrix_1_1Csr.html#a2d1d5b4b310ed444ccbb178e241a9822", null ],
    [ "create_value_view", "classgko_1_1matrix_1_1Csr.html#ad0f3a8d348dc828dd32da8c6b4bf93f7", null ],
    [ "extract_diagonal", "classgko_1_1matrix_1_1Csr.html#a75ddc647a3998ca75e15ac8cd29c24ce", null ],
    [ "get_col_idxs", "classgko_1_1matrix_1_1Csr.html#ae701fb37da0c745c314fb3472cef5df4", null ],
    [ "get_const_col_idxs", "classgko_1_1matrix_1_1Csr.html#ac3a1ef745f900fd534999a69eae3ff32", null ],
    [ "get_const_row_ptrs", "classgko_1_1matrix_1_1Csr.html#a29e603a026ca798346e74ee8408b2f51", null ],
    [ "get_const_srow", "classgko_1_1matrix_1_1Csr.html#a396e0e99ce4fefca9dcbe45e4fccc838", null ],
    [ "get_const_values", "classgko_1_1matrix_1_1Csr.html#aad85907f0b9717618ed5dabcd56e4e39", null ],
    [ "get_num_srow_elements", "classgko_1_1matrix_1_1Csr.html#a5b8c25c2fb1bbea62a3afdec8f8340c5", null ],
    [ "get_num_stored_elements", "classgko_1_1matrix_1_1Csr.html#ab70c085fc3df11a4ed9fe74b40844c5c", null ],
    [ "get_row_ptrs", "classgko_1_1matrix_1_1Csr.html#a83f2a63175bbffa39808543a3d4b3f3b", null ],
    [ "get_srow", "classgko_1_1matrix_1_1Csr.html#a4a8d2975871fdd779e447a8ef9e991d1", null ],
    [ "get_strategy", "classgko_1_1matrix_1_1Csr.html#abb20626b04360436259fdc13b00e59b0", null ],
    [ "get_values", "classgko_1_1matrix_1_1Csr.html#ade22bdc09b0ef6d9740feeaa702fdd51", null ],
    [ "inv_scale", "classgko_1_1matrix_1_1Csr.html#a3ed41ecd59dcfe1b805ed910fada56a9", null ],
    [ "operator=", "classgko_1_1matrix_1_1Csr.html#a0f8038628e96f1995e4942863415ad63", null ],
    [ "operator=", "classgko_1_1matrix_1_1Csr.html#a96d132e8d22d7565f93540eb50bcc32c", null ],
    [ "permute", "classgko_1_1matrix_1_1Csr.html#a898b9b458ff9e26c87c277fba3a9bdae", null ],
    [ "permute", "classgko_1_1matrix_1_1Csr.html#af0538658a2fad819129927dbd39de0ae", null ],
    [ "permute_reuse", "classgko_1_1matrix_1_1Csr.html#a05d792d40944735476606320d91290f4", null ],
    [ "permute_reuse", "classgko_1_1matrix_1_1Csr.html#a6059f7474424460e1e0c25f5bf2c7c37", null ],
    [ "scale", "classgko_1_1matrix_1_1Csr.html#ad1db62aaad519a9774dde49ff411edde", null ],
    [ "scale_permute", "classgko_1_1matrix_1_1Csr.html#a1c3c66d3baf3b05e52992b6f3f7611f7", null ],
    [ "scale_permute", "classgko_1_1matrix_1_1Csr.html#acf9d804a766061d117e78a3534b2e80d", null ],
    [ "set_strategy", "classgko_1_1matrix_1_1Csr.html#a3e0f6f2a9d773de0551068d514bf9703", null ],
    [ "sort_by_column_index", "classgko_1_1matrix_1_1Csr.html#ac817665ebedfc099180a785d813db8ef", null ],
    [ "transpose", "classgko_1_1matrix_1_1Csr.html#aaa850dcdfabfc020918fa870e50c0b11", null ],
    [ "transpose_reuse", "classgko_1_1matrix_1_1Csr.html#accf30d10cf9b83da853b72c138fb192f", null ]
];
